@@ -1,10 +1,13 @@
 
 
 #' @title Get the total number of failed reproduction attempts
+#'
+#' @param envir Environment to retrieve data from. This defaults to a internal package namespace.
+#'
 #' @returns Returns the number of errors encountered when reproducing a Markdown document
 #' @export
-get_num_reproducibility_errors <- function() {
-  num_errors <- get0(x = "repror_error_counter", envir=knitr::knit_global())
+get_num_reproducibility_errors <- function(envir=.cache) {
+  num_errors <- get0(x = "repror_error_counter", envir=envir)
   if (is.null(num_errors)) num_errors <- 0
   return(num_errors)
 }
@@ -18,10 +21,13 @@ get_num_reproducibility_errors <- function() {
 #' was tested. `Chunk` stores the name of the surrounding chunk, `Variable`
 #' stores the name of the variable, and `Success` is a boolean variable,
 #' which indicates whether the reproduction attempt was successful.
+#'
+#' @param envir Environment to retrieve data from. This defaults to a internal package namespace.
+#'
 #' @returns Returns a data.frame with three columns.
 #' @export
-get_reproducibility_summary <- function() {
-  get0(x = "repror_summary", envir=knitr::knit_global())
+get_reproducibility_summary <- function(envir=.cache) {
+  get0(x = "repror_summary", envir=envir)
 }
 
 
