@@ -1,7 +1,16 @@
 test_that("mixing hashed and non-hashed JSON data works", {
-  fname <- testthat::test_path("testdata","test2.Rmd")
-  foutname <- testthat::test_path("testdata","test2.pdf")
+
+  path <- testthat::test_path("testdata")
+  fname <- "test2.Rmd"
+  foutname <- "test2.pdf"
+
+
+  lastwd <- getwd()
+  setwd(normalizePath(path))
+
   knitr::knit(input=fname,output = foutname)
 
   testthat::expect_true(file.exists(foutname))
+
+  setwd(lastwd)
 })
