@@ -1,7 +1,12 @@
 test_that("potentially problematic variable names are stored correctly", {
-  fname <- testthat::test_path("testdata","test3.Rmd")
-  foutname <- testthat::test_path("testdata","test3.html")
+  path <- testthat::test_path("testdata")
+  fname <- "test3.Rmd"
+  foutname <- "test3.html"
+  lastwd <- getwd()
+  setwd(normalizePath(path))
   knitr::knit(input=fname,output = foutname)
-
   testthat::expect_true(file.exists(foutname))
+  setwd(lastwd)
+
+
 })
